==> apache-tez-0.8.2-src.tar.gz: apache-tez-0.8.2-src/docs/src/site/markdown/releases/apache-tez-0-8-0-alpha.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
-->

<head><title>Apache Tez 0.8.0-alpha</title></head>

Apache Tez 0.8.0-alpha
----------------------

- [Release Artifacts](http://www.apache.org/dyn/closer.lua/tez/0.8.0-alpha/)
- [Release Notes](0.8.0-alpha/release-notes.txt)
- Documentation
    - [API Javadocs](0.8.0-alpha/tez-api-javadocs/index.html) : Documentation for the Tez APIs
    - [Runtime Library Javadocs](0.8.0-alpha/tez-runtime-library-javadocs/index.html) : Documentation for built-in implementations of useful Inputs, Outputs, Processors etc. written based on the Tez APIs 
    - [Tez Mapreduce Javadocs](0.8.0-alpha/tez-mapreduce-javadocs/index.html) : Documentation for built-in implementations of Mapreduce compatible Inputs, Outputs, Processors etc. written based on the Tez APIs

==> apache-tez-0.8.5-src.tar.gz: apache-tez-0.8.5-src/docs/src/site/markdown/releases/apache-tez-0-8-0-alpha.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
-->

<head><title>Apache Tez&trade; 0.8.0-alpha</title></head>

Apache Tez&trade; 0.8.0-alpha
----------------------

- [Download Release Artifacts](http://archive.apache.org/dist/tez/0.8.0-alpha/)
- [Release Notes](0.8.0-alpha/release-notes.txt)
- Documentation
    - [API Javadocs](0.8.0-alpha/tez-api-javadocs/index.html) : Documentation for the Tez APIs
    - [Runtime Library Javadocs](0.8.0-alpha/tez-runtime-library-javadocs/index.html) : Documentation for built-in implementations of useful Inputs, Outputs, Processors etc. written based on the Tez APIs 
    - [Tez Mapreduce Javadocs](0.8.0-alpha/tez-mapreduce-javadocs/index.html) : Documentation for built-in implementations of Mapreduce compatible Inputs, Outputs, Processors etc. written based on the Tez APIs
